@@ -266,10 +266,10 @@ var nicEditorConfig = bkClass.extend({
 		'removeformat' : {name : __('Remove Formatting'), command : 'removeformat', noActive : true},
 		'indent' : {name : __('Indent Text'), command : 'indent', noActive : true},
 		'outdent' : {name : __('Remove Indent'), command : 'outdent', noActive : true},
-		'hr' : {name : __('Horizontal Rule'), command : 'insertHorizontalRule', noActive : true},
+		'hr' : {name : __('Horizontal Rule'), command : 'insertHorizontalRule', noActive : true}
 	},
-	iconsPath : '/static/img/niceditoricons.gif',
-	buttonList : ['save','bold','italic','underline','left','center','right','justify','ol','ul','fontSize','fontFamily','fontFormat','indent','outdent','image','upload','link','unlink','forecolor','bgcolor','xhtml'],
+	iconsPath : '/static/img/nicEditorIcons.gif',
+	buttonList : ['save','bold','italic','underline','left','center','right','justify','ol','ul','fontSize','fontFamily','fontFormat','indent','outdent','image','upload','link','unlink','forecolor','bgcolor'],
 	iconList : {"xhtml":1,"bgcolor":2,"forecolor":3,"bold":4,"center":5,"hr":6,"indent":7,"italic":8,"justify":9,"left":10,"ol":11,"outdent":12,"removeformat":13,"right":14,"save":25,"strikethrough":16,"subscript":17,"superscript":18,"ul":19,"underline":20,"image":21,"link":22,"unlink":23,"close":24,"arrow":26,"upload":27}
 	
 });
@@ -1365,7 +1365,8 @@ var nicUploadOptions = {
 };
 /* END CONFIG */
 
-var nicUploadButton = nicEditorAdvancedButton.extend({
+var nicUploadButton = nicEditorAdvancedButton.extend({	
+	nicURI : 'http://api.imgur.com/2/upload.json',
   errorText : 'Failed to upload image',
 
 	addPane : function() {
@@ -1413,7 +1414,7 @@ var nicUploadButton = nicEditorAdvancedButton.extend({
     fd.append("image", file);
     fd.append("csrfmiddlewaretoken", document.getElementsByName("csrfmiddlewaretoken")[0].value);
     var xhr = new XMLHttpRequest();
-    xhr.open("POST", this.ne.options.uploadURI);
+    xhr.open("POST", this.ne.options.uploadURI || this.nicURI);
 
     xhr.onload = function() {
       try {
